==> aliyun-python-sdk-oceanbasepro-1.0.5.tar.gz: aliyun-python-sdk-oceanbasepro-1.0.5/aliyunsdkoceanbasepro/request/v20190901/DeleteInstancesRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkoceanbasepro.endpoint import endpoint_data

class DeleteInstancesRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'OceanBasePro', '2019-09-01', 'DeleteInstances','oceanbase')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_BackupRetainMode(self): # String
		return self.get_body_params().get('BackupRetainMode')

	def set_BackupRetainMode(self, BackupRetainMode):  # String
		self.add_body_params('BackupRetainMode', BackupRetainMode)
	def get_InstanceIds(self): # String
		return self.get_body_params().get('InstanceIds')

	def set_InstanceIds(self, InstanceIds):  # String
		self.add_body_params('InstanceIds', InstanceIds)

==> aliyun-python-sdk-oceanbasepro-1.0.15.tar.gz: aliyun-python-sdk-oceanbasepro-1.0.15/aliyunsdkoceanbasepro/request/v20190901/DeleteInstancesRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkoceanbasepro.endpoint import endpoint_data

class DeleteInstancesRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'OceanBasePro', '2019-09-01', 'DeleteInstances','oceanbase')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_BackupRetainMode(self): # String
		return self.get_body_params().get('BackupRetainMode')

	def set_BackupRetainMode(self, BackupRetainMode):  # String
		self.add_body_params('BackupRetainMode', BackupRetainMode)
	def get_DryRun(self): # Boolean
		return self.get_body_params().get('DryRun')

	def set_DryRun(self, DryRun):  # Boolean
		self.add_body_params('DryRun', DryRun)
	def get_InstanceIds(self): # String
		return self.get_body_params().get('InstanceIds')

	def set_InstanceIds(self, InstanceIds):  # String
		self.add_body_params('InstanceIds', InstanceIds)
